###############################################################################
## Arcadia Project
##
## Copyright (C) 2009-2010 Arcadia Project arcadia.videogame@gmail.com http://www.arcadiaproject.org/
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
###############################################################################

import pygame
from lib import FileManager
from Game import Game
from game.intro.Fondo import Fondo
from game.intro.Solapa import Solapa
from game.intro.Arcadios import Arcadios
from lib.Shadows import *
from game.selectPlayer.SelectPlayer import SelectPlayer

class MainMenu(Game):
    """clase principal del menu del juego"""
    def __init__(self, core):
        Game.__init__(self,core)
        self.core = core
        self.core.fondo = Fondo(self.core, (0,0))
        self.core.fondo2 = Fondo(self.core, (self.core.screen_width, 0))
        self.solapa = Solapa(self.core)
        self.selected = 1

        #creamos las surfaces del texto del menu

        self.core.font.selectCustomFont("kimbalt_", 60)

        if self.core.screen_height < 768:
            positionTop = 0.65
        else:
            positionTop = 0.75

        #play
        self.play = self.core.font.renderText("Jugar", self.core.screen_width * 0.5,self.core.screen_height * positionTop, (255,255,255), "center", "center")
        self.play_shadow = add_shadow(self.play.getSurface(), (4,4))
        self.play.setSurface(self.play_shadow)

        self.play_selected = self.core.font.renderText("Jugar", self.core.screen_width * 0.5,self.core.screen_height * positionTop, (255,0,0), "center", "center")
        self.play_selected_shadow = add_shadow(self.play_selected.getSurface(), (4,4))
        self.play_selected.setSurface(self.play_selected_shadow)

        #options
        self.options = self.core.font.renderText("Opciones", self.core.screen_width * 0.5,self.core.screen_height * positionTop +70, (255,255,255), "center", "center")
        self.options_shadow = add_shadow(self.options.getSurface(), (4,4))
        self.options.setSurface(self.options_shadow)

        self.options_selected = self.core.font.renderText("Opciones", self.core.screen_width * 0.5,self.core.screen_height * positionTop +70, (255,0,0), "center", "center")
        self.options_selected_shadow = add_shadow(self.options_selected.getSurface(), (4,4))
        self.options_selected.setSurface(self.options_selected_shadow)

        #exit
        self.exit = self.core.font.renderText("Salir", self.core.screen_width * 0.5,self.core.screen_height * positionTop +140, (255,255,255), "center", "center")
        self.exit_shadow = add_shadow(self.exit.getSurface(), (4,4))
        self.exit.setSurface(self.exit_shadow)

        self.exit_selected = self.core.font.renderText("Salir", self.core.screen_width * 0.5,self.core.screen_height * positionTop + 140, (255,0,0), "center", "center")
        self.exit_selected_shadow = add_shadow(self.exit_selected.getSurface(), (4,4))
        self.exit_selected.setSurface(self.exit_selected_shadow)

        self.core.font.selectCustomFont("kimbalt_", 14)

        self.info = self.core.font.renderText("Usa Arriba - Abajo o Izquierda - Derecha para navegar", self.core.screen_width * 0.01, self.core.screen_height - self.core.screen_height * 0.01, (255,0,0), "left", "bottom")
        nuevainfo = add_shadow(self.info.getSurface(), (1,1))
        self.info.setSurface(nuevainfo)


    def paint(self):
        self.paintItem(self.core.fondo)
        self.paintItem(self.core.fondo2)
        self.paintItem(self.solapa)

        
        if pygame.time.get_ticks() > 2400:
            if (self.selected == 1):
                self.paintItem(self.play_selected)
            else:
                self.paintItem(self.play)

            if (self.selected == 2):
                self.paintItem(self.options_selected)
            else:
                self.paintItem(self.options)

            if (self.selected == 3):
                self.paintItem(self.exit_selected)
            else:
                self.paintItem(self.exit)

            self.paintItem(self.info)

    def logic(self):
        self.core.fondo.ia()
        self.core.fondo2.ia()
        self.solapa.ia()

    def controls(self):
        """rescatamos las funciones de mapeado general del juego y el resto lo delegamos al minijuego"""
        if self.core.controlManager.controlSimple.count(("KEYBUTTON", pygame.K_DOWN)) > 0:
            self.selected += 1
            if self.selected > 3:
                self.selected = 1
            self.core.controlManager.controlSimple.pop(self.core.controlManager.controlSimple.index(("KEYBUTTON", pygame.K_DOWN)))

        if self.core.controlManager.controlSimple.count(("KEYBUTTON", pygame.K_RIGHT)) > 0:
            self.selected += 1
            if self.selected > 3:
                self.selected = 1
            self.core.controlManager.controlSimple.pop(self.core.controlManager.controlSimple.index(("KEYBUTTON", pygame.K_RIGHT)))

        if self.core.controlManager.controlSimple.count(("KEYBUTTON", pygame.K_UP)) > 0:
            self.selected -= 1
            if self.selected < 1:
                self.selected = 3
            self.core.controlManager.controlSimple.pop(self.core.controlManager.controlSimple.index(("KEYBUTTON", pygame.K_UP)))

        if self.core.controlManager.controlSimple.count(("KEYBUTTON", pygame.K_LEFT)) > 0:
            self.selected -= 1
            if self.selected < 1:
                self.selected = 3
            self.core.controlManager.controlSimple.pop(self.core.controlManager.controlSimple.index(("KEYBUTTON", pygame.K_LEFT)))

        if self.core.controlManager.controlSimple.count(("KEYBUTTON", pygame.K_RETURN)) > 0 and self.selected == 1:
            self.core.game = self.core.games[1]
            self.core.controlManager.controlSimple.pop(self.core.controlManager.controlSimple.index(("KEYBUTTON", pygame.K_RETURN)))


        if self.core.controlManager.controlSimple.count(("KEYBUTTON", pygame.K_RETURN)) > 0 and self.selected == 2:
            self.core.game = self.core.games[4]
            self.core.controlManager.controlSimple.pop(self.core.controlManager.controlSimple.index(("KEYBUTTON", pygame.K_RETURN)))

        if self.core.controlManager.controlSimple.count(("KEYBUTTON", pygame.K_RETURN)) > 0 and self.selected == 3:
            self.core.controlManager.running = False
            self.core.controlManager.controlSimple.pop(self.core.controlManager.controlSimple.index(("KEYBUTTON", pygame.K_RETURN)))

        if self.core.controlManager.controlSimple.count(("KEYBUTTON", pygame.K_f)) > 0:
            self.core.toggleFullScreen()
            self.core.controlManager.controlSimple.pop(self.core.controlManager.controlSimple.index(("KEYBUTTON", pygame.K_f)))
            
        
